@@ -87,6 +87,7 @@ impl Artifact {
             Artifact::Solid2d(a) => vec![a.path_id],
             Artifact::StartSketchOnFace(a) => vec![a.face_id],
             Artifact::StartSketchOnPlane(a) => vec![a.plane_id],
+            Artifact::PlaneOfFace(a) => vec![a.face_id],
             Artifact::Sweep(a) => vec![a.path_id],
             Artifact::Wall(a) => vec![a.seg_id, a.sweep_id],
             Artifact::Cap(a) => vec![a.sweep_id],
@@ -151,6 +152,10 @@ impl Artifact {
                 // Note: Don't include these since they're parents: plane_id.
                 Vec::new()
             }
+            Artifact::PlaneOfFace { .. } => {
+                // Note: Don't include these since they're parents: face_id.
+                Vec::new()
+            }
             Artifact::Sweep(a) => {
                 // Note: Don't include these since they're parents: path_id.
                 let mut ids = Vec::new();
@@ -262,6 +267,7 @@ impl ArtifactGraph {
                 }
                 Artifact::StartSketchOnFace { .. }
                 | Artifact::StartSketchOnPlane { .. }
+                | Artifact::PlaneOfFace { .. }
                 | Artifact::Sweep(_)
                 | Artifact::Wall(_)
                 | Artifact::Cap(_)
@@ -381,6 +387,14 @@ impl ArtifactGraph {
                 )?;
                 node_path_display(output, prefix, None, code_ref)?;
             }
+            Artifact::PlaneOfFace(PlaneOfFace { code_ref, .. }) => {
+                writeln!(
+                    output,
+                    "{prefix}{id}[\"PlaneOfFace<br>{:?}\"]",
+                    code_ref_display(code_ref)
+                )?;
+                node_path_display(output, prefix, None, code_ref)?;
+            }
             Artifact::Sweep(sweep) => {
                 writeln!(
                     output,
