@@ -768,7 +768,13 @@ impl GetTangentialInfoFromPathsResult {
 }
 
 impl Sketch {
-    pub(crate) fn add_tag(&mut self, tag: NodeRef<'_, TagDeclarator>, current_path: &Path, exec_state: &ExecState) {
+    pub(crate) fn add_tag(
+        &mut self,
+        tag: NodeRef<'_, TagDeclarator>,
+        current_path: &Path,
+        exec_state: &ExecState,
+        surface: Option<&ExtrudeSurface>,
+    ) {
         let mut tag_identifier: TagIdentifier = tag.into();
         let base = current_path.get_base();
         tag_identifier.info.push((
@@ -777,7 +783,7 @@ impl Sketch {
                 id: base.geo_meta.id,
                 sketch: self.id,
                 path: Some(current_path.clone()),
-                surface: None,
+                surface: surface.cloned(),
             },
         ));
 
@@ -1608,6 +1614,24 @@ impl ExtrudeSurface {
         }
     }
 
+    pub fn face_id(&self) -> uuid::Uuid {
+        match self {
+            ExtrudeSurface::ExtrudePlane(ep) => ep.face_id,
+            ExtrudeSurface::ExtrudeArc(ea) => ea.face_id,
+            ExtrudeSurface::Fillet(f) => f.face_id,
+            ExtrudeSurface::Chamfer(c) => c.face_id,
+        }
+    }
+
+    pub fn set_face_id(&mut self, face_id: uuid::Uuid) {
+        match self {
+            ExtrudeSurface::ExtrudePlane(ep) => ep.face_id = face_id,
+            ExtrudeSurface::ExtrudeArc(ea) => ea.face_id = face_id,
+            ExtrudeSurface::Fillet(f) => f.face_id = face_id,
+            ExtrudeSurface::Chamfer(c) => c.face_id = face_id,
+        }
+    }
+
     pub fn get_tag(&self) -> Option<Node<TagDeclarator>> {
         match self {
             ExtrudeSurface::ExtrudePlane(ep) => ep.tag.clone(),
