@@ -1,20 +1,22 @@
 use std::collections::HashMap;
 
 use anyhow::Result;
-use schemars::JsonSchema;
+use indexmap::IndexMap;
+use kittycad_modeling_cmds::units::UnitLength;
 use serde::Serialize;
 
 use crate::{
     CompilationError, KclError, ModuleId, SourceRange,
     errors::KclErrorDetails,
     execution::{
-        EnvironmentRef, ExecState, Face, Geometry, GeometryWithImportedGeometry, Helix, ImportedGeometry, MetaSettings,
-        Metadata, Plane, Sketch, Solid, TagIdentifier,
-        annotations::{SETTINGS, SETTINGS_UNIT_LENGTH},
-        types::{NumericType, PrimitiveType, RuntimeType, UnitLen},
+        EnvironmentRef, ExecState, Face, Geometry, GeometryWithImportedGeometry, Helix, ImportedGeometry, Metadata,
+        Plane, Sketch, Solid, TagIdentifier,
+        annotations::{self, FnAttrs, SETTINGS, SETTINGS_UNIT_LENGTH},
+        types::{NumericType, PrimitiveType, RuntimeType},
     },
     parsing::ast::types::{
-        DefaultParamVal, FunctionExpression, KclNone, Literal, LiteralValue, Node, TagDeclarator, TagNode,
+        DefaultParamVal, FunctionExpression, KclNone, Literal, LiteralValue, Node, NumericLiteral, TagDeclarator,
+        TagNode, Type,
     },
     std::{StdFnProps, args::TyF64},
 };
@@ -22,7 +24,7 @@ use crate::{
 pub type KclObjectFields = HashMap<String, KclValue>;
 
 /// Any KCL value.
-#[derive(Debug, Clone, Serialize, PartialEq, ts_rs::TS, JsonSchema)]
+#[derive(Debug, Clone, Serialize, PartialEq, ts_rs::TS)]
 #[ts(export)]
 #[serde(tag = "type")]
 pub enum KclValue {
@@ -61,6 +63,7 @@ pub enum KclValue {
     },
     Object {
         value: KclObjectFields,
+        constrainable: bool,
         #[serde(skip)]
         meta: Vec<Metadata>,
     },
@@ -85,7 +88,7 @@ pub enum KclValue {
     Function {
         #[serde(serialize_with = "function_value_stub")]
         #[ts(type = "null")]
-        value: FunctionSource,
+        value: Box<FunctionSource>,
         #[serde(skip)]
         meta: Vec<Metadata>,
     },
@@ -98,6 +101,7 @@ pub enum KclValue {
     Type {
         #[serde(skip)]
         value: TypeDef,
+        experimental: bool,
         #[serde(skip)]
         meta: Vec<Metadata>,
     },
@@ -115,31 +119,91 @@ where
     serializer.serialize_unit()
 }
 
-#[derive(Debug, Clone, PartialEq, Default)]
-pub enum FunctionSource {
-    #[default]
-    None,
-    Std {
-        func: crate::std::StdFn,
-        ast: crate::parsing::ast::types::BoxNode<FunctionExpression>,
-        props: StdFnProps,
-    },
-    User {
-        ast: crate::parsing::ast::types::BoxNode<FunctionExpression>,
-        settings: MetaSettings,
-        memory: EnvironmentRef,
-    },
+#[derive(Debug, Clone, PartialEq)]
+pub struct FunctionSource {
+    pub input_arg: Option<(String, Option<Type>)>,
+    pub named_args: IndexMap<String, (Option<DefaultParamVal>, Option<Type>)>,
+    pub return_type: Option<Node<Type>>,
+    pub deprecated: bool,
+    pub experimental: bool,
+    pub include_in_feature_tree: bool,
+    pub is_std: bool,
+    pub body: FunctionBody,
+    pub ast: crate::parsing::ast::types::BoxNode<FunctionExpression>,
 }
 
-impl JsonSchema for FunctionSource {
-    fn schema_name() -> String {
-        "FunctionSource".to_owned()
+impl FunctionSource {
+    pub fn rust(
+        func: crate::std::StdFn,
+        ast: Box<Node<FunctionExpression>>,
+        props: StdFnProps,
+        attrs: FnAttrs,
+    ) -> Self {
+        let (input_arg, named_args) = Self::args_from_ast(&ast);
+
+        FunctionSource {
+            input_arg,
+            named_args,
+            return_type: ast.return_type.clone(),
+            deprecated: attrs.deprecated,
+            experimental: attrs.experimental,
+            include_in_feature_tree: props.include_in_feature_tree,
+            is_std: true,
+            body: FunctionBody::Rust(func),
+            ast,
+        }
     }
 
-    fn json_schema(r#gen: &mut schemars::r#gen::SchemaGenerator) -> schemars::schema::Schema {
-        // TODO: Actually generate a reasonable schema.
-        r#gen.subschema_for::<()>()
+    pub fn kcl(ast: Box<Node<FunctionExpression>>, memory: EnvironmentRef, is_std: bool) -> Self {
+        let (input_arg, named_args) = Self::args_from_ast(&ast);
+        FunctionSource {
+            input_arg,
+            named_args,
+            return_type: ast.return_type.clone(),
+            deprecated: false,
+            experimental: false,
+            include_in_feature_tree: true,
+            is_std,
+            body: FunctionBody::Kcl(memory),
+            ast,
+        }
     }
+
+    #[allow(clippy::type_complexity)]
+    fn args_from_ast(
+        ast: &FunctionExpression,
+    ) -> (
+        Option<(String, Option<Type>)>,
+        IndexMap<String, (Option<DefaultParamVal>, Option<Type>)>,
+    ) {
+        let mut input_arg = None;
+        let mut named_args = IndexMap::new();
+        for p in &ast.params {
+            if !p.labeled {
+                input_arg = Some((
+                    p.identifier.name.clone(),
+                    p.param_type.as_ref().map(|t| t.inner.clone()),
+                ));
+                continue;
+            }
+
+            named_args.insert(
+                p.identifier.name.clone(),
+                (p.default_value.clone(), p.param_type.as_ref().map(|t| t.inner.clone())),
+            );
+        }
+
+        (input_arg, named_args)
+    }
+}
+
+#[derive(Debug, Clone, PartialEq)]
+// If you try to compare two `crate::std::StdFn` the results will be meaningless and arbitrary,
+// because they're just function pointers.
+#[allow(unpredictable_function_pointer_comparisons)]
+pub enum FunctionBody {
+    Rust(crate::std::StdFn),
+    Kcl(EnvironmentRef),
 }
 
 #[derive(Debug, Clone, PartialEq)]
@@ -253,7 +317,7 @@ impl KclValue {
             KclValue::String { value: _, meta } => meta.clone(),
             KclValue::Tuple { value: _, meta } => meta.clone(),
             KclValue::HomArray { value, .. } => value.iter().flat_map(|v| v.metadata()).collect(),
-            KclValue::Object { value: _, meta } => meta.clone(),
+            KclValue::Object { meta, .. } => meta.clone(),
             KclValue::TagIdentifier(x) => x.meta.clone(),
             KclValue::TagDeclarator(x) => vec![x.metadata()],
             KclValue::Plane { value } => value.meta.clone(),
@@ -358,27 +422,39 @@ impl KclValue {
         }
     }
 
+    pub(crate) fn from_numeric_literal(literal: &Node<NumericLiteral>, exec_state: &mut ExecState) -> Self {
+        let meta = vec![literal.metadata()];
+        let ty = NumericType::from_parsed(literal.suffix, &exec_state.mod_local.settings);
+        KclValue::Number {
+            value: literal.value,
+            meta,
+            ty,
+        }
+    }
+
     pub(crate) fn from_literal(literal: Node<Literal>, exec_state: &mut ExecState) -> Self {
         let meta = vec![literal.metadata()];
         match literal.inner.value {
             LiteralValue::Number { value, suffix } => {
                 let ty = NumericType::from_parsed(suffix, &exec_state.mod_local.settings);
-                if let NumericType::Default { len, .. } = &ty {
-                    if !exec_state.mod_local.explicit_length_units && *len != UnitLen::Mm {
-                        exec_state.warn(
-                            CompilationError::err(
-                                literal.as_source_range(),
-                                "Project-wide units are deprecated. Prefer to use per-file default units.",
-                            )
-                            .with_suggestion(
-                                "Fix by adding per-file settings",
-                                format!("@{SETTINGS}({SETTINGS_UNIT_LENGTH} = {len})\n"),
-                                // Insert at the start of the file.
-                                Some(SourceRange::new(0, 0, literal.module_id)),
-                                crate::errors::Tag::Deprecated,
-                            ),
-                        );
-                    }
+                if let NumericType::Default { len, .. } = &ty
+                    && !exec_state.mod_local.explicit_length_units
+                    && *len != UnitLength::Millimeters
+                {
+                    exec_state.warn(
+                        CompilationError::err(
+                            literal.as_source_range(),
+                            "Project-wide units are deprecated. Prefer to use per-file default units.",
+                        )
+                        .with_suggestion(
+                            "Fix by adding per-file settings",
+                            format!("@{SETTINGS}({SETTINGS_UNIT_LENGTH} = {len})\n"),
+                            // Insert at the start of the file.
+                            Some(SourceRange::new(0, 0, literal.module_id)),
+                            crate::errors::Tag::Deprecated,
+                        ),
+                        annotations::WARN_DEPRECATED,
+                    );
                 }
                 KclValue::Number { value, meta, ty }
             }
@@ -399,13 +475,15 @@ impl KclValue {
 
     pub(crate) fn map_env_ref(&self, old_env: usize, new_env: usize) -> Self {
         let mut result = self.clone();
-        if let KclValue::Function {
-            value: FunctionSource::User { ref mut memory, .. },
-            ..
-        } = result
+        if let KclValue::Function { ref mut value, .. } = result
+            && let FunctionSource {
+                body: FunctionBody::Kcl(memory),
+                ..
+            } = &mut **value
         {
             memory.replace_env(old_env, new_env);
         }
+
         result
     }
 
@@ -726,7 +804,7 @@ mod tests {
     fn test_human_friendly_type() {
         let len = KclValue::Number {
             value: 1.0,
-            ty: NumericType::Known(UnitType::Length(UnitLen::Unknown)),
+            ty: NumericType::Known(UnitType::GenericLength),
             meta: vec![],
         };
         assert_eq!(len.human_friendly_type(), "a number (Length)".to_string());
@@ -740,7 +818,7 @@ mod tests {
 
         let mm = KclValue::Number {
             value: 1.0,
-            ty: NumericType::Known(UnitType::Length(UnitLen::Mm)),
+            ty: NumericType::Known(UnitType::Length(UnitLength::Millimeters)),
             meta: vec![],
         };
         assert_eq!(mm.human_friendly_type(), "a number (mm)".to_string());
@@ -774,7 +852,7 @@ mod tests {
 
         let inches = KclValue::Number {
             value: 1.0,
-            ty: NumericType::Known(UnitType::Length(UnitLen::Inches)),
+            ty: NumericType::Known(UnitType::Length(UnitLength::Inches)),
             meta: vec![],
         };
         let array4 = KclValue::HomArray {
