@@ -526,7 +526,12 @@ impl NumericType {
     ///
     /// This combinator function is suitable for comparisons where uncertainty should
     /// be handled by the user.
-    pub fn combine_eq(a: TyF64, b: TyF64) -> (f64, f64, NumericType) {
+    pub fn combine_eq(
+        a: TyF64,
+        b: TyF64,
+        exec_state: &mut ExecState,
+        source_range: SourceRange,
+    ) -> (f64, f64, NumericType) {
         use NumericType::*;
         match (a.ty, b.ty) {
             (at, bt) if at == bt => (a.n, b.n, at),
@@ -546,8 +551,24 @@ impl NumericType {
             }
             (t @ Known(UnitType::Length(l1)), Default { len: l2, .. }) if l1 == l2 => (a.n, b.n, t),
             (Default { len: l1, .. }, t @ Known(UnitType::Length(l2))) if l1 == l2 => (a.n, b.n, t),
-            (t @ Known(UnitType::Angle(a1)), Default { angle: a2, .. }) if a1 == a2 => (a.n, b.n, t),
-            (Default { angle: a1, .. }, t @ Known(UnitType::Angle(a2))) if a1 == a2 => (a.n, b.n, t),
+            (t @ Known(UnitType::Angle(a1)), Default { angle: a2, .. }) if a1 == a2 => {
+                if b.n != 0.0 {
+                    exec_state.warn(
+                        CompilationError::err(source_range, "Prefer to use explicit units for angles"),
+                        annotations::WARN_ANGLE_UNITS,
+                    );
+                }
+                (a.n, b.n, t)
+            }
+            (Default { angle: a1, .. }, t @ Known(UnitType::Angle(a2))) if a1 == a2 => {
+                if a.n != 0.0 {
+                    exec_state.warn(
+                        CompilationError::err(source_range, "Prefer to use explicit units for angles"),
+                        annotations::WARN_ANGLE_UNITS,
+                    );
+                }
+                (a.n, b.n, t)
+            }
 
             _ => (a.n, b.n, Unknown),
         }
@@ -560,7 +581,11 @@ impl NumericType {
     /// coerced together, for example two arguments to the same function or two numbers in an array being used as a point.
     ///
     /// Prefer to use `combine_eq` if possible since using that prioritises correctness over ergonomics.
-    pub fn combine_eq_coerce(a: TyF64, b: TyF64) -> (f64, f64, NumericType) {
+    pub fn combine_eq_coerce(
+        a: TyF64,
+        b: TyF64,
+        for_errs: Option<(&mut ExecState, SourceRange)>,
+    ) -> (f64, f64, NumericType) {
         use NumericType::*;
         match (a.ty, b.ty) {
             (at, bt) if at == bt => (a.n, b.n, at),
@@ -583,13 +608,53 @@ impl NumericType {
 
             (t @ Known(UnitType::Length(l1)), Default { len: l2, .. }) => (a.n, adjust_length(l2, b.n, l1).0, t),
             (Default { len: l1, .. }, t @ Known(UnitType::Length(l2))) => (adjust_length(l1, a.n, l2).0, b.n, t),
-            (t @ Known(UnitType::Angle(a1)), Default { angle: a2, .. }) => (a.n, adjust_angle(a2, b.n, a1).0, t),
-            (Default { angle: a1, .. }, t @ Known(UnitType::Angle(a2))) => (adjust_angle(a1, a.n, a2).0, b.n, t),
+            (t @ Known(UnitType::Angle(a1)), Default { angle: a2, .. }) => {
+                if let Some((exec_state, source_range)) = for_errs
+                    && b.n != 0.0
+                {
+                    exec_state.warn(
+                        CompilationError::err(source_range, "Prefer to use explicit units for angles"),
+                        annotations::WARN_ANGLE_UNITS,
+                    );
+                }
+                (a.n, adjust_angle(a2, b.n, a1).0, t)
+            }
+            (Default { angle: a1, .. }, t @ Known(UnitType::Angle(a2))) => {
+                if let Some((exec_state, source_range)) = for_errs
+                    && a.n != 0.0
+                {
+                    exec_state.warn(
+                        CompilationError::err(source_range, "Prefer to use explicit units for angles"),
+                        annotations::WARN_ANGLE_UNITS,
+                    );
+                }
+                (adjust_angle(a1, a.n, a2).0, b.n, t)
+            }
 
             (Default { len: l1, .. }, Known(UnitType::GenericLength)) => (a.n, b.n, l1.into()),
             (Known(UnitType::GenericLength), Default { len: l2, .. }) => (a.n, b.n, l2.into()),
-            (Default { angle: a1, .. }, Known(UnitType::GenericAngle)) => (a.n, b.n, a1.into()),
-            (Known(UnitType::GenericAngle), Default { angle: a2, .. }) => (a.n, b.n, a2.into()),
+            (Default { angle: a1, .. }, Known(UnitType::GenericAngle)) => {
+                if let Some((exec_state, source_range)) = for_errs
+                    && b.n != 0.0
+                {
+                    exec_state.warn(
+                        CompilationError::err(source_range, "Prefer to use explicit units for angles"),
+                        annotations::WARN_ANGLE_UNITS,
+                    );
+                }
+                (a.n, b.n, a1.into())
+            }
+            (Known(UnitType::GenericAngle), Default { angle: a2, .. }) => {
+                if let Some((exec_state, source_range)) = for_errs
+                    && a.n != 0.0
+                {
+                    exec_state.warn(
+                        CompilationError::err(source_range, "Prefer to use explicit units for angles"),
+                        annotations::WARN_ANGLE_UNITS,
+                    );
+                }
+                (a.n, b.n, a2.into())
+            }
 
             (Known(_), Known(_)) | (Default { .. }, Default { .. }) | (_, Unknown) | (Unknown, _) => {
                 (a.n, b.n, Unknown)
@@ -2354,14 +2419,18 @@ b = 180 / PI * a + 360
     #[tokio::test(flavor = "multi_thread")]
     async fn cos_coercions() {
         let program = r#"
-a = cos(units::toRadians(30))
+a = cos(units::toRadians(30deg))
 b = 3 / a
 c = cos(30deg)
-d = cos(30)
+d = cos(1rad)
 "#;
 
         let result = parse_execute(program).await.unwrap();
-        assert!(result.exec_state.errors().is_empty());
+        assert!(
+            result.exec_state.errors().is_empty(),
+            "{:?}",
+            result.exec_state.errors()
+        );
 
         assert_value_and_type("a", &result, 1.0, NumericType::default());
         assert_value_and_type("b", &result, 3.0, NumericType::default());
