@@ -228,7 +228,7 @@ async fn inner_circle(
     let mut new_sketch = sketch;
     new_sketch.is_closed = true;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -330,7 +330,7 @@ async fn inner_circle_three_point(
     let mut new_sketch = sketch;
     new_sketch.is_closed = true;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -633,7 +633,7 @@ async fn inner_ellipse(
     let mut new_sketch = sketch;
     new_sketch.is_closed = true;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
