@@ -167,6 +167,8 @@ async fn inner_involute_circular(
     args: Args,
 ) -> Result<Sketch, KclError> {
     let id = exec_state.next_uuid();
+    let angle_deg = angle.to_degrees(exec_state, args.source_range);
+    let angle_rad = angle.to_radians(exec_state, args.source_range);
 
     let longer_args_dot_source_range = args.source_range;
     let start_radius = get_radius_labelled(
@@ -192,7 +194,7 @@ async fn inner_involute_circular(
                 segment: PathSegment::CircularInvolute {
                     start_radius: LengthUnit(start_radius.to_mm()),
                     end_radius: LengthUnit(end_radius.to_mm()),
-                    angle: Angle::from_degrees(angle.to_degrees()),
+                    angle: Angle::from_degrees(angle_deg),
                     reverse: reverse.unwrap_or_default(),
                 },
             }),
@@ -208,11 +210,11 @@ async fn inner_involute_circular(
     let theta = f64::sqrt(end_radius * end_radius - start_radius * start_radius) / start_radius;
     let (x, y) = involute_curve(start_radius, theta);
 
-    end.x = x * libm::cos(angle.to_radians()) - y * libm::sin(angle.to_radians());
-    end.y = x * libm::sin(angle.to_radians()) + y * libm::cos(angle.to_radians());
+    end.x = x * libm::cos(angle_rad) - y * libm::sin(angle_rad);
+    end.y = x * libm::sin(angle_rad) + y * libm::cos(angle_rad);
 
-    end.x -= start_radius * libm::cos(angle.to_radians());
-    end.y -= start_radius * libm::sin(angle.to_radians());
+    end.x -= start_radius * libm::cos(angle_rad);
+    end.y -= start_radius * libm::sin(angle_rad);
 
     if reverse.unwrap_or_default() {
         end.x = -end.x;
@@ -236,7 +238,7 @@ async fn inner_involute_circular(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
     new_sketch.paths.push(current_path);
     Ok(new_sketch)
@@ -372,7 +374,7 @@ async fn straight_line(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -590,7 +592,7 @@ async fn inner_angled_line_length(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -769,7 +771,7 @@ pub async fn inner_angled_line_that_intersects(
             point_to_len_unit(path.get_to(), from.units),
         ],
         offset.map(|t| t.to_length_units(from.units)).unwrap_or_default(),
-        angle.to_degrees(),
+        angle.to_degrees(exec_state, args.source_range),
         from.ignore_units(),
     );
     let to = [
@@ -1280,7 +1282,7 @@ pub(crate) async fn inner_close(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
     new_sketch.paths.push(current_path);
     new_sketch.is_closed = true;
@@ -1406,7 +1408,7 @@ pub async fn absolute_arc(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -1426,8 +1428,8 @@ pub async fn relative_arc(
     radius: TyF64,
     tag: Option<TagNode>,
 ) -> Result<Sketch, KclError> {
-    let a_start = Angle::from_degrees(angle_start.to_degrees());
-    let a_end = Angle::from_degrees(angle_end.to_degrees());
+    let a_start = Angle::from_degrees(angle_start.to_degrees(exec_state, args.source_range));
+    let a_end = Angle::from_degrees(angle_end.to_degrees(exec_state, args.source_range));
     let radius = radius.to_length_units(from.units);
     let (center, end) = arc_center_and_end(from.ignore_units(), a_start, a_end, radius);
     if a_start == a_end {
@@ -1474,7 +1476,7 @@ pub async fn relative_arc(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -1581,7 +1583,7 @@ async fn inner_tangential_arc_radius_angle(
     let (center, to, ccw) = match data {
         TangentialArcData::RadiusAndOffset { radius, offset } => {
             // KCL stdlib types use degrees.
-            let offset = Angle::from_degrees(offset.to_degrees());
+            let offset = Angle::from_degrees(offset.to_degrees(exec_state, args.source_range));
 
             // Calculate the end point from the angle and radius.
             // atan2 outputs radians.
@@ -1643,7 +1645,7 @@ async fn inner_tangential_arc_radius_angle(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -1732,7 +1734,7 @@ async fn inner_tangential_arc_to_point(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -1859,7 +1861,7 @@ async fn inner_bezier_curve(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -2060,8 +2062,8 @@ pub(crate) async fn inner_elliptic(
             },
         ],
     };
-    let start_angle = Angle::from_degrees(angle_start.to_degrees());
-    let end_angle = Angle::from_degrees(angle_end.to_degrees());
+    let start_angle = Angle::from_degrees(angle_start.to_degrees(exec_state, args.source_range));
+    let end_angle = Angle::from_degrees(angle_end.to_degrees(exec_state, args.source_range));
     let major_axis_magnitude = (major_axis[0].to_length_units(from.units) * major_axis[0].to_length_units(from.units)
         + major_axis[1].to_length_units(from.units) * major_axis[1].to_length_units(from.units))
     .sqrt();
@@ -2111,7 +2113,7 @@ pub(crate) async fn inner_elliptic(
     };
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -2275,7 +2277,7 @@ pub(crate) async fn inner_hyperbolic(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -2488,7 +2490,7 @@ pub(crate) async fn inner_parabolic(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
@@ -2642,7 +2644,7 @@ pub(crate) async fn inner_conic(
 
     let mut new_sketch = sketch;
     if let Some(tag) = &tag {
-        new_sketch.add_tag(tag, &current_path, exec_state);
+        new_sketch.add_tag(tag, &current_path, exec_state, None);
     }
 
     new_sketch.paths.push(current_path);
