@@ -2,14 +2,19 @@
 use anyhow::Result;
 use kcl_lib::{
     lint::{checks, Discovered},
-    ExecutorContext, UnitLength,
+    ExecutorContext,
+};
+use kittycad_modeling_cmds::{
+    self as kcmc, format::InputFormat3d, shared::FileExportFormat, units::UnitLength, websocket::RawFile, ImageFormat,
+    ImportFile,
 };
-use kittycad_modeling_cmds as kcmc;
 use pyo3::{
-    prelude::PyModuleMethods, pyclass, pyfunction, pymethods, pymodule, types::PyModule, wrap_pyfunction, Bound, PyErr,
-    PyResult,
+    exceptions::PyException, prelude::PyModuleMethods, pyclass, pyfunction, pymethods, pymodule, types::PyModule,
+    wrap_pyfunction, Bound, PyErr, PyResult, Python,
 };
+use pyo3_stub_gen::define_stub_info_gatherer;
 use serde::{Deserialize, Serialize};
+use uuid::Uuid;
 
 mod bridge;
 
@@ -35,105 +40,9 @@ fn into_miette_for_parse(filename: &str, input: &str, error: kcl_lib::KclError)
     pyo3::exceptions::PyException::new_err(format!("{report:?}"))
 }
 
-/// The variety of image formats snapshots may be exported to.
-#[derive(Serialize, Deserialize, PartialEq, Hash, Debug, Clone, Copy)]
-#[pyclass(eq, eq_int)]
-#[serde(rename_all = "lowercase")]
-pub enum ImageFormat {
-    /// .png format
-    Png,
-    /// .jpeg format
-    Jpeg,
-}
-
-impl From<ImageFormat> for kittycad_modeling_cmds::ImageFormat {
-    fn from(format: ImageFormat) -> Self {
-        match format {
-            ImageFormat::Png => kittycad_modeling_cmds::ImageFormat::Png,
-            ImageFormat::Jpeg => kittycad_modeling_cmds::ImageFormat::Jpeg,
-        }
-    }
-}
-
-/// A file that was exported from the engine.
-#[derive(Serialize, Deserialize, PartialEq, Debug, Clone)]
-#[pyclass]
-pub struct ExportFile {
-    /// Binary contents of the file.
-    pub contents: Vec<u8>,
-    /// Name of the file.
-    pub name: String,
-}
-
-impl From<kittycad_modeling_cmds::shared::ExportFile> for ExportFile {
-    fn from(file: kittycad_modeling_cmds::shared::ExportFile) -> Self {
-        ExportFile {
-            contents: file.contents.0,
-            name: file.name,
-        }
-    }
-}
-
-impl From<kittycad_modeling_cmds::websocket::RawFile> for ExportFile {
-    fn from(file: kittycad_modeling_cmds::websocket::RawFile) -> Self {
-        ExportFile {
-            contents: file.contents,
-            name: file.name,
-        }
-    }
-}
-
-#[pymethods]
-impl ExportFile {
-    #[getter]
-    fn contents(&self) -> Vec<u8> {
-        self.contents.clone()
-    }
-
-    #[getter]
-    fn name(&self) -> String {
-        self.name.clone()
-    }
-}
-
-/// The valid types of output file formats.
-#[derive(Serialize, Deserialize, PartialEq, Hash, Debug, Clone)]
-#[pyclass(eq, eq_int)]
-#[serde(rename_all = "lowercase")]
-pub enum FileExportFormat {
-    /// Autodesk Filmbox (FBX) format. <https://en.wikipedia.org/wiki/FBX>
-    Fbx,
-    /// Binary glTF 2.0.
-    ///
-    /// This is a single binary with .glb extension.
-    ///
-    /// This is better if you want a compressed format as opposed to the human readable glTF that lacks
-    /// compression.
-    Glb,
-    /// glTF 2.0. Embedded glTF 2.0 (pretty printed).
-    ///
-    /// Single JSON file with .gltf extension binary data encoded as base64 data URIs.
-    ///
-    /// The JSON contents are pretty printed.
-    ///
-    /// It is human readable, single file, and you can view the diff easily in a
-    /// git commit.
-    Gltf,
-    /// The OBJ file format. <https://en.wikipedia.org/wiki/Wavefront_.obj_file> It may or
-    /// may not have an an attached material (mtl // mtllib) within the file, but we
-    /// interact with it as if it does not.
-    Obj,
-    /// The PLY file format. <https://en.wikipedia.org/wiki/PLY_(file_format)>
-    Ply,
-    /// The STEP file format. <https://en.wikipedia.org/wiki/ISO_10303-21>
-    Step,
-    /// The STL file format. <https://en.wikipedia.org/wiki/STL_(file_format)>
-    Stl,
-}
-
 fn get_output_format(
     format: &FileExportFormat,
-    src_unit: kittycad_modeling_cmds::units::UnitLength,
+    src_unit: UnitLength,
 ) -> kittycad_modeling_cmds::format::OutputFormat3d {
     // Zoo co-ordinate system.
     //
@@ -238,6 +147,7 @@ async fn new_context_state(
 }
 
 /// Parse the kcl code from a file path.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 async fn parse(path: String) -> PyResult<bool> {
     tokio()
@@ -255,6 +165,7 @@ async fn parse(path: String) -> PyResult<bool> {
 }
 
 /// Parse the kcl code.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 fn parse_code(code: String) -> PyResult<bool> {
     let _program = kcl_lib::Program::parse_no_errs(&code).map_err(|err| into_miette_for_parse("", &code, err))?;
@@ -263,6 +174,7 @@ fn parse_code(code: String) -> PyResult<bool> {
 }
 
 /// Execute the kcl code from a file path.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 async fn execute(path: String) -> PyResult<()> {
     tokio()
@@ -288,6 +200,7 @@ async fn execute(path: String) -> PyResult<()> {
 }
 
 /// Execute the kcl code.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 async fn execute_code(code: String) -> PyResult<()> {
     tokio()
@@ -310,6 +223,7 @@ async fn execute_code(code: String) -> PyResult<()> {
 }
 
 /// Mock execute the kcl code.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 async fn mock_execute_code(code: String) -> PyResult<bool> {
     tokio()
@@ -332,6 +246,7 @@ async fn mock_execute_code(code: String) -> PyResult<bool> {
 }
 
 /// Mock execute the kcl code from a file path.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 async fn mock_execute(path: String) -> PyResult<bool> {
     tokio()
@@ -356,13 +271,89 @@ async fn mock_execute(path: String) -> PyResult<bool> {
         .map_err(|err| pyo3::exceptions::PyException::new_err(err.to_string()))?
 }
 
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
+#[pyfunction]
+async fn import_and_snapshot(
+    filepaths: Vec<String>,
+    format: InputFormat3d,
+    image_format: ImageFormat,
+) -> PyResult<Vec<u8>> {
+    let img = import_and_snapshot_views(filepaths, format, image_format, Vec::new())
+        .await?
+        .pop();
+    Ok(img.unwrap())
+}
+
+fn to_py_exception(err: impl std::fmt::Display) -> PyErr {
+    PyException::new_err(err.to_string())
+}
+
+/// Get the allowed relevant file extensions (imports + kcl).
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
+#[pyfunction]
+fn relevant_file_extensions() -> PyResult<Vec<String>> {
+    Ok(kcl_lib::RELEVANT_FILE_EXTENSIONS
+        .iter()
+        .map(|s| s.to_string())
+        .collect::<Vec<String>>())
+}
+
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
+#[pyfunction]
+async fn import_and_snapshot_views(
+    filepaths: Vec<String>,
+    format: InputFormat3d,
+    image_format: ImageFormat,
+    snapshot_options: Vec<SnapshotOptions>,
+) -> PyResult<Vec<Vec<u8>>> {
+    tokio()
+        .spawn(async move {
+            let (ctx, _state) = new_context_state(None, false).await.map_err(to_py_exception)?;
+            import(&ctx, filepaths, format).await?;
+            take_snaps(&ctx, image_format, snapshot_options).await
+        })
+        .await
+        .map_err(|err| pyo3::exceptions::PyException::new_err(err.to_string()))?
+}
+
+/// Return the ID of the imported object.
+async fn import(ctx: &ExecutorContext, filepaths: Vec<String>, format: InputFormat3d) -> PyResult<Uuid> {
+    let mut files = Vec::with_capacity(filepaths.len());
+    for filepath in filepaths {
+        let file_contents = tokio::fs::read(&filepath).await.map_err(to_py_exception)?;
+        files.push(ImportFile {
+            path: filepath,
+            data: file_contents,
+        });
+    }
+    let resp = ctx
+        .engine
+        .send_modeling_cmd(
+            Uuid::new_v4().into(),
+            Default::default(),
+            &kcmc::ModelingCmd::ImportFiles(kcmc::ImportFiles { files, format }),
+        )
+        .await?;
+    let kittycad_modeling_cmds::websocket::OkWebSocketResponseData::Modeling {
+        modeling_response: kittycad_modeling_cmds::ok_response::OkModelingCmdResponse::ImportFiles(data),
+    } = resp
+    else {
+        return Err(pyo3::exceptions::PyException::new_err(format!(
+            "Unexpected response from engine: {resp:?}",
+        )));
+    };
+    Ok(data.object_id)
+}
+
 /// Execute a kcl file and snapshot it in a specific format.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 async fn execute_and_snapshot(path: String, image_format: ImageFormat) -> PyResult<Vec<u8>> {
     let img = execute_and_snapshot_views(path, image_format, Vec::new()).await?.pop();
     Ok(img.unwrap())
 }
 
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 async fn execute_and_snapshot_views(
     path: String,
@@ -392,6 +383,7 @@ async fn execute_and_snapshot_views(
 }
 
 /// Execute the kcl code and snapshot it in a specific format.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 async fn execute_code_and_snapshot(code: String, image_format: ImageFormat) -> PyResult<Vec<u8>> {
     let mut snaps = execute_code_and_snapshot_views(code, image_format, Vec::new()).await?;
@@ -400,6 +392,7 @@ async fn execute_code_and_snapshot(code: String, image_format: ImageFormat) -> P
 
 /// Customize a snapshot.
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone)]
+#[pyo3_stub_gen::derive::gen_stub_pyclass]
 #[pyclass]
 pub struct SnapshotOptions {
     /// If none, will use isometric view.
@@ -411,6 +404,7 @@ pub struct SnapshotOptions {
     pub padding: f32,
 }
 
+#[pyo3_stub_gen::derive::gen_stub_pymethods]
 #[pymethods]
 impl SnapshotOptions {
     #[new]
@@ -429,6 +423,7 @@ impl SnapshotOptions {
 /// Execute the kcl code and snapshot it in a specific format.
 /// Returns one image for each camera angle you provide.
 /// If you don't provide any camera angles, a default head-on camera angle will be used.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 async fn execute_code_and_snapshot_views(
     code: String,
@@ -523,8 +518,9 @@ async fn snapshot(ctx: &ExecutorContext, image_format: ImageFormat, padding: f32
 }
 
 /// Execute a kcl file and export it to a specific file format.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
-async fn execute_and_export(path: String, export_format: FileExportFormat) -> PyResult<Vec<ExportFile>> {
+async fn execute_and_export(path: String, export_format: FileExportFormat) -> PyResult<Vec<RawFile>> {
     tokio()
         .spawn(async move {
             let (code, path) = get_code_and_file_path(&path)
@@ -566,15 +562,16 @@ async fn execute_and_export(path: String, export_format: FileExportFormat) -> Py
                 )));
             };
 
-            Ok(files.into_iter().map(ExportFile::from).collect())
+            Ok(files)
         })
         .await
         .map_err(|err| pyo3::exceptions::PyException::new_err(err.to_string()))?
 }
 
 /// Execute the kcl code and export it to a specific file format.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
-async fn execute_code_and_export(code: String, export_format: FileExportFormat) -> PyResult<Vec<ExportFile>> {
+async fn execute_code_and_export(code: String, export_format: FileExportFormat) -> PyResult<Vec<RawFile>> {
     tokio()
         .spawn(async move {
             let program =
@@ -613,13 +610,14 @@ async fn execute_code_and_export(code: String, export_format: FileExportFormat)
                 )));
             };
 
-            Ok(files.into_iter().map(ExportFile::from).collect())
+            Ok(files)
         })
         .await
         .map_err(|err| pyo3::exceptions::PyException::new_err(err.to_string()))?
 }
 
 /// Format the kcl code. This will return the formatted code.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 fn format(code: String) -> PyResult<String> {
     let program = kcl_lib::Program::parse_no_errs(&code).map_err(|err| into_miette_for_parse("", &code, err))?;
@@ -629,6 +627,7 @@ fn format(code: String) -> PyResult<String> {
 }
 
 /// Format a whole directory of kcl code.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 async fn format_dir(dir: String) -> PyResult<()> {
     tokio()
@@ -642,6 +641,7 @@ async fn format_dir(dir: String) -> PyResult<()> {
 }
 
 /// Lint the kcl code.
+#[pyo3_stub_gen::derive::gen_stub_pyfunction]
 #[pyfunction]
 fn lint(code: String) -> PyResult<Vec<Discovered>> {
     let program = kcl_lib::Program::parse_no_errs(&code).map_err(|err| into_miette_for_parse("", &code, err))?;
@@ -654,16 +654,30 @@ fn lint(code: String) -> PyResult<Vec<Discovered>> {
 
 /// The kcl python module.
 #[pymodule]
-fn kcl(m: &Bound<'_, PyModule>) -> PyResult<()> {
+fn kcl(_py: Python, m: &Bound<'_, PyModule>) -> PyResult<()> {
     // Add our types to the module.
     m.add_class::<ImageFormat>()?;
-    m.add_class::<ExportFile>()?;
+    m.add_class::<RawFile>()?;
     m.add_class::<FileExportFormat>()?;
     m.add_class::<UnitLength>()?;
     m.add_class::<Discovered>()?;
     m.add_class::<SnapshotOptions>()?;
     m.add_class::<bridge::Point3d>()?;
     m.add_class::<bridge::CameraLookAt>()?;
+    m.add_class::<kcmc::format::InputFormat3d>()?;
+
+    // These are fine to add top level since we rename them in pyo3 derives.
+    m.add_class::<kcmc::format::step::import::Options>()?;
+    m.add_class::<kcmc::format::step::export::Options>()?;
+    m.add_class::<kcmc::format::gltf::import::Options>()?;
+    m.add_class::<kcmc::format::gltf::export::Options>()?;
+    m.add_class::<kcmc::format::obj::import::Options>()?;
+    m.add_class::<kcmc::format::obj::export::Options>()?;
+    m.add_class::<kcmc::format::ply::import::Options>()?;
+    m.add_class::<kcmc::format::ply::export::Options>()?;
+    m.add_class::<kcmc::format::stl::import::Options>()?;
+    m.add_class::<kcmc::format::stl::export::Options>()?;
+    m.add_class::<kcmc::format::sldprt::import::Options>()?;
 
     // Add our functions to the module.
     m.add_function(wrap_pyfunction!(parse, m)?)?;
@@ -676,10 +690,16 @@ fn kcl(m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(execute_and_snapshot_views, m)?)?;
     m.add_function(wrap_pyfunction!(execute_code_and_snapshot, m)?)?;
     m.add_function(wrap_pyfunction!(execute_code_and_snapshot_views, m)?)?;
+    m.add_function(wrap_pyfunction!(import_and_snapshot, m)?)?;
+    m.add_function(wrap_pyfunction!(import_and_snapshot_views, m)?)?;
     m.add_function(wrap_pyfunction!(execute_and_export, m)?)?;
     m.add_function(wrap_pyfunction!(execute_code_and_export, m)?)?;
     m.add_function(wrap_pyfunction!(format, m)?)?;
     m.add_function(wrap_pyfunction!(format_dir, m)?)?;
     m.add_function(wrap_pyfunction!(lint, m)?)?;
+    m.add_function(wrap_pyfunction!(relevant_file_extensions, m)?)?;
     Ok(())
 }
+
+// Define a function to gather stub information.
+define_stub_info_gatherer!(stub_info);
